@@ -48,13 +48,10 @@ class IMobilethemeTwoSettings(form.Schema):
     scrape_url_pair = schema.List(
         title = "Url Pair Fields",
         value_type=DictRow(schema=IUrlPair),
-        required=False
     )
                   
     scrape_url = schema.URI(
-                title='scrape_url', 'default url'),
-                description=_('scrape_url',
-                            u'Base url if none is given'),
+                title='scrape_url',
     )
                       
     scrape_javascript = schema.Bool(
